QBroker is short for Quick Access Broker.

QBroker is a minimal wrapper for asynchronous, debuggable RPC via AMQP.
It uses Python 3.4 asyncio features and provides wrappers for use with
native threads or gevent tasks.

Example scripts, including a monitor which can watch RPC calls and replies,
are provided.

QBroker is written in Python. If you know JSON and AMQP, writing a server
or client in a different language is reasonably straightforward.

